====================
Uvod
====================


.. raw:: latex

    \pagenumbering{arabic}


Nezamenljivi žetoni
===========================
Nezamenljivi žetoni (angl. *Non fungible tokens*) so edinstvena digitalna sredstva, ki živijo na 
verigi blokov brez možnosti replikacije.
Najpogosteje predstavljajo digitalna umetniška dela :ref:`nft_what_is`.


.. figure:: ./DEP/example_bunny_nft.png
    :width: 5cm

    Primer nezameljivega žetona (ustvaril `DALL-E <https://openai.com/dall-e-2/>`_)


Nezamenljivost pomeni, da posameznega žetona ni mogoče preprosto zamenjati za drugega, kot se lahko menja
sod olja za drug sod olja ali en evro za drug evro.

Najbližji primer nezamenljivega žetona v fizični obliki je bejzbolska kartica. Na primer, lahko imate zelo redko
bejzbolsko kartico nekega igralca bejzbola in je ne morete enakovredno zamenjati za kakšno drugo, običajno bejzbolsko kartico.

Marketinški pristopi za promoviranje nezamenljivih žetonov
===========================================================
Obstaja več načinov oglaševanja, ki se jih lahko uporabi tudi za oglaševanje nezamenljivih žetonov. Ti so na primer
uporaba Google Ads platforme (oglaševanje po Google iskalniku, YouTube aplikaciji), uporaba forumov in drugi načini.
Eden izmed teh drugih načinov je morda še najbolj uveljavljen na tem področju, in sicer ga imenujemo
agresivno oglaševanje (angl. *shilling*) :ref:`nft_shilling`.

Pri agresivnem oglaševanju ni postavljanja promocijskega gradiva na spletno stran ali stojnice v javnost, temveč
gre za nenehno objavljanje informacij o izdelku na socialna omrežja, kot so Instagram, Telegram, Discord ipd.,
omenjanje izdelka in deljenje povezav do njega povsod, kjer je to mogoče.

Te dni prodajalci nezamenljivih žetonov pogosto ne oglašujejo samostojno, temveč najamejo ljudi, ki to delo 
opravljajo namesto njih. Obstaja veliko ponudb za taka dela, ki so lahko zelo profitabilna, še posebej če imate
orodje, ki lahko oglašuje namesto človeka, avtomatično, brez da bi bil ta prisoten.

To diplomsko delo se ne osredotoča na same nezamenljive žetone, temveč na proces oglaševanja, in sicer na socialnem
omrežju Discord. Delo se navezuje na projekt Ogrodje za oglaševanje po Discordu (angl. *Discord Advertisement Framework*), ki je
ogrodje za oglaševanje, napisano v programskem jeziku `Python <https://www.python.org>`_.

.. raw:: latex

    \newpage
